# -*- coding: utf-8 -*-
# type: ignore
from __future__ import annotations

from pytest_mock import MockerFixture

from keep_it_secret import fields
from keep_it_secret.secrets import Secrets


def test_init():
    # When
    result = fields.LiteralField('spam')

    # Then
    assert result.as_type is None
    assert result.value == 'spam'


def test_init_with_field_options():
    # When
    result = fields.LiteralField(
        'spam', as_type=int, required=False, description='eggs',
    )

    # Then
    assert result.as_type is None
    assert result.required is False
    assert result.description == 'eggs'


def test_new(mocker: MockerFixture):
    # Given
    mock_init = mocker.patch.object(
        fields.LiteralField, '__init__', return_value=None,
    )

    # When
    _ = fields.LiteralField.new(
        'spam', as_type=int, required=False, description='eggs',
    )

    # Then
    mock_init.assert_called_once_with(
        'spam', as_type=int, required=False, description='eggs',
    )


def test_get_value(testing_secrets: Secrets):
    # Given
    field = fields.LiteralField('spam')

    # When
    result = field.get_value(testing_secrets)

    # Then
    assert result == 'spam'
